@@ -31,6 +31,7 @@ myApp.controller("smsgatewayController", function($scope, $stateParams,
     $scope.form = {};
     $scope.gateway_id = $stateParams.gateway_id;
     $scope.opts = {};
+    $scope.headers = {};
 
     // Get all gateway definitions
     $scope.getSMSGateways = function (gwid) {
@@ -42,7 +43,7 @@ myApp.controller("smsgatewayController", function($scope, $stateParams,
                 $scope.form = $scope.smsgateways[0];
                 $scope.form.module = $scope.form.providermodule;
                 var option_array = Object.keys($scope.smsproviders[$scope.form.module].parameters);
-                // fill all parameters
+                // fill all parameters (default options and additional options)
                 angular.forEach(Object.keys($scope.form.options),
                     function (optionname) {
                         if (option_array.indexOf(optionname)>-1) {
@@ -52,6 +53,8 @@ myApp.controller("smsgatewayController", function($scope, $stateParams,
                             $scope.opts[optionname] = $scope.form.options[optionname];
                         }
                     });
+                // fill all parameters (headers)
+                $scope.headers = $scope.form.headers
             }
         });
     };
@@ -80,8 +83,15 @@ myApp.controller("smsgatewayController", function($scope, $stateParams,
                 $scope.form["option." + option] = $scope.opts[option];
             }
         }
+        // transform the event headers to form parameters
+        for (var header in $scope.headers) {
+            if ($scope.headers.hasOwnProperty(header)) {
+                $scope.form["header." + header] = $scope.headers[header];
+            }
+        }
 
         delete $scope.form.options;
+        delete $scope.form.headers;
         ConfigFactory.setSMSGateway($scope.form, function() {
             $state.go("config.smsgateway.list");
             $('html,body').scrollTop(0);
@@ -104,6 +114,16 @@ myApp.controller("smsgatewayController", function($scope, $stateParams,
         $scope.newvalue = "";
     };
 
+     $scope.deleteHeader = function(headername) {
+        delete $scope.headers[headername];
+    };
+
+    $scope.addHeader = function() {
+        $scope.headers[$scope.newheader] = $scope.newheadervalue;
+        $scope.newheader = "";
+        $scope.newheadervalue = "";
+    };
+
     // listen to the reload broadcast
     $scope.$on("piReload", $scope.getSMSGateways);
 });
