@@ -60,39 +60,6 @@ myApp.controller("tokenController", function (TokenFactory, ConfigFactory,
         }
     };
 
-    if ($scope.loggedInUser.role === "admin") {
-        /*
-        * Functions to check and to create a default realm. At the moment this is
-        * in the tokenview, as the token view is the first view. This could be
-        * changed to be located anywhere else.
-        */
-        ConfigFactory.getRealms(function (data) {
-            // Check if there is a realm defined, or if we should display the
-            // Auto Create Dialog
-            var number_of_realms = Object.keys(data.result.value).length;
-            if (number_of_realms === 0) {
-                $('#dialogAutoCreateRealm').modal();
-            }
-        });
-        /*
-         Welcome dialog, which displays a lot of information to the
-         administrator.
-
-         We display it if
-         subscription_state = 0 and hide_welcome = false
-         subscription_state = 1
-         subscription_state = 2
-         */
-        if ($scope.welcomeStep < 4) {
-            // We did not walk through the welcome dialog, yet.
-            if (($scope.subscription_state === 0 && !$scope.hide_welcome) ||
-                ($scope.subscription_state === 1) ||
-                ($scope.subscription_state === 2)) {
-                $('#dialogWelcome').modal("show");
-            }
-        }
-    }
-
     // single token function
     $scope.reset = function (serial) {
         TokenFactory.reset(serial, $scope.get);
@@ -135,9 +102,11 @@ myApp.controller("tokenController", function (TokenFactory, ConfigFactory,
 });
 
 
-myApp.controller("tokenAssignController", function ($scope, TokenFactory,
-                                                    $stateParams, AuthFactory,
-                                                    UserFactory, $state) {
+myApp.controller("tokenAssignController", ['$scope', 'TokenFactory',
+                                           '$stateParams', 'AuthFactory',
+                                           'UserFactory', '$state',
+    function tokenAssignController($scope, TokenFactory, $stateParams,
+                                   AuthFactory, UserFactory, $state) {
     $scope.assignToken = function () {
         TokenFactory.assign({
             serial: fixSerial($scope.newToken.serial),
@@ -146,16 +115,21 @@ myApp.controller("tokenAssignController", function ($scope, TokenFactory,
             $state.go('token.list');
         });
     };
-});
+}]);
 
-myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
-                                                    $timeout,
-                                                    $stateParams, AuthFactory,
-                                                    UserFactory, $state,
-                                                    ConfigFactory, instanceUrl,
-                                                    $http, hotkeys,
-                                                    gettextCatalog,
-                                                    inform, U2fFactory, webAuthnToken) {
+myApp.controller("tokenEnrollController", ["$scope", "TokenFactory", "$timeout",
+                                           "$stateParams", "AuthFactory",
+                                           "UserFactory", "$state",
+                                           "ConfigFactory", "instanceUrl",
+                                           "$http", "hotkeys", "gettextCatalog",
+                                           "inform", "U2fFactory",
+                                           "webAuthnToken",
+                                           "versioningSuffixProvider",
+    function tokenEnrollController($scope, TokenFactory, $timeout, $stateParams,
+                                   AuthFactory, UserFactory, $state,
+                                   ConfigFactory, instanceUrl, $http, hotkeys,
+                                   gettextCatalog, inform, U2fFactory,
+                                   webAuthnToken, versioningSuffixProvider) {
 
     hotkeys.bindTo($scope).add({
         combo: 'alt+e',
@@ -177,9 +151,8 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
     $scope.qrCodeWidth = 250;
 
     if ($state.includes('token.wizard') && !$scope.show_seed) {
-        $scope.qrCodeWidth = 500;
+        $scope.qrCodeWidth = 300;
     }
-
     $scope.checkRight = AuthFactory.checkRight;
     $scope.loggedInUser = AuthFactory.getUser();
     $scope.newUser = {};
@@ -193,6 +166,7 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
     // questions for questionnaire token
     $scope.questions = [];
     $scope.num_questions = 5;
+    $scope.fileVersionSuffix = versioningSuffixProvider.$get();
     // These are values that are also sent to the backend!
     $scope.form = {
         timeStep: 30,
@@ -206,6 +180,7 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
         // Note: A primitive does not work in the ng-model of the checkbox!
         useIt: false
     };
+    $scope.enrolling = false;
 
     $scope.formInit = {
         tokenTypes: {"hotp": gettextCatalog.getString("HOTP: event based One Time Passwords"),
@@ -287,6 +262,19 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
         } else {
             $scope.form.genkey = true;
         }
+        if ($scope.form.type === "yubikey") {
+            // save the original otp length
+            $scope.old_otplen = $scope.form.otplen;
+            // set the default otp length for yubikeys in AES mode to 44
+            // (12 characters (6 bytes) UID and 32 characters (16 bytes) OTP)
+            $scope.form.otplen = 44;
+        } else {
+            // restore old otp length if available
+            if (typeof $scope.old_otplen != "undefined") {
+                $scope.form.otplen = $scope.old_otplen;
+                delete $scope.old_otplen;
+            }
+        }
 
         $scope.preset_indexedsecret();
 
@@ -413,6 +401,8 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
                 $scope.form.type = tkey;
                 // Set the 2step enrollment value
                 $scope.setTwostepEnrollmentDefault();
+                // Initialize token specific settings
+                $scope.changeTokenType();
                 break;
             }
         }
@@ -468,6 +458,7 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
     };
 
     $scope.enrollToken = function () {
+        $scope.enrolling = true;
         //debug: console.log($scope.newUser.user);
         //debug: console.log($scope.newUser.realm);
         //debug: console.log($scope.newUser.pin);
@@ -515,12 +506,9 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
     };
 
     $scope.yubikeyGetLen = function () {
-        if ($scope.tempData.yubikeyTest.length >= 32) {
-            $scope.form.otplen = $scope.tempData.yubikeyTest.length;
-            if ($scope.tempData.yubikeyTest.length > 32) {
-                $scope.tempData.yubikeyUid = true;
-                $scope.tempData.yubikeyUidLen = $scope.tempData.yubikeyTest.length - 32;
-            }
+        let yktestdatalen = $scope.tempData.yubikeyTest.trim().length;
+        if (yktestdatalen >= 32) {
+            $scope.form.otplen = yktestdatalen;
         }
     };
 
@@ -640,7 +628,7 @@ myApp.controller("tokenEnrollController", function ($scope, TokenFactory,
         startingDay: 1
     };
 
-});
+}]);
 
 
 myApp.controller("tokenImportController", function ($scope, Upload,
@@ -679,11 +667,13 @@ myApp.controller("tokenImportController", function ($scope, Upload,
                 data: {file: file,
                     type: $scope.form.type,
                     psk: $scope.form.psk,
+                    pskcValidateMAC: $scope.form.validateMAC,
                     password: $scope.form.password,
                     tokenrealms: $scope.form.realm},
             }).then(function (resp) {
                 $scope.uploadedFile = resp.config.data.file.name;
-                $scope.uploadedTokens = resp.data.result.value;
+                $scope.uploadedTokens = resp.data.result.value.n_imported;
+                $scope.notImportedTokens = resp.data.result.value.n_not_imported;
             }, function (error) {
                 if (error.data.result.error.code === -401) {
                     $state.go('login');
