@@ -317,6 +317,16 @@ class AuditTestCase(MyTestCase):
         # The tokentype was actually written as token_type
         self.assertEqual(audit_log.auditdata[0].get("token_type"), "spass")
 
+    def test_11_check_audit_columns(self):
+        self.Audit.log({"action": "test11"})
+        self.Audit.finalize_log()
+        audit_log = self.Audit.search({"action": "test11"})
+        self.assertEqual(audit_log.total, 1)
+        # The tokentype was actually written as token_type
+        self.assertEqual(set(audit_log.auditdata[0].keys()),
+                         set(self.Audit.available_audit_columns),
+                         audit_log.auditdata[0].keys())
+
 
 class AuditColumnLengthTestCase(OverrideConfigTestCase):
     class Config(TestingConfig):
