@@ -16,11 +16,12 @@ getToken....
 from .base import MyTestCase, FakeAudit, FakeFlaskG
 from privacyidea.lib.user import (User)
 from privacyidea.lib.tokenclass import TokenClass, TOKENKIND, FAILCOUNTER_EXCEEDED, FAILCOUNTER_CLEAR_TIMEOUT
+from privacyidea.lib.token import weigh_token_type
 from privacyidea.lib.tokens.totptoken import TotpTokenClass
 from privacyidea.models import (Token, Challenge, TokenRealm)
 from privacyidea.lib.config import (set_privacyidea_config, get_token_types, delete_privacyidea_config, SYSCONF)
 from privacyidea.lib.policy import set_policy, SCOPE, ACTION, delete_policy, PolicyClass, delete_policy
-from privacyidea.lib.utils import b32encode_and_unicode
+from privacyidea.lib.utils import b32encode_and_unicode, hexlify_and_unicode
 from privacyidea.lib.error import PolicyError
 import datetime
 from dateutil import parser
@@ -1527,6 +1528,45 @@ class TokenTestCase(MyTestCase):
                           {"serial": "invalid/chars",
                            "genkey": 1})
 
+    def test_57_registration_token_no_auth_counter(self):
+        # Test, that a registration token is deleted even if no_auth_counter is used.
+        from privacyidea.lib.config import set_privacyidea_config, delete_privacyidea_config
+        set_privacyidea_config("no_auth_counter", 1)
+        tok = init_token({"type": "registration"})
+        serial = tok.token.serial
+        detail = tok.get_init_detail()
+        reg_password = detail.get("registrationcode")
+        r, rdetail = check_token_list([tok], reg_password)
+        self.assertTrue(r)
+        self.assertEqual(rdetail["message"], "matching 1 tokens")
+        delete_privacyidea_config("no_auth_counter")
+        # Check that the token is deleted
+        toks = get_tokens(serial=serial)
+        self.assertEqual(len(toks), 0)
+
+    def test_58_check_old_pin(self):
+        serial = "pins"
+        tokenobject = init_token({"serial": serial,
+                                  "otpkey": "1234567890123456"})
+        # now set the old pin
+        from privacyidea.lib.crypto import hash
+        tokenobject.token.pin_hash = hash("1234", b"1234567890")
+        tokenobject.token.pin_seed = hexlify_and_unicode(b"1234567890")
+        tokenobject.token.save()
+        r = tokenobject.token.check_pin("1234")
+        self.assertTrue(r)
+        remove_token(serial)
+
+    def test_59_weigh_token_types(self):
+
+        class dummy_token(object):
+            def __init__(self, type):
+                self.type = type
+        self.assertEqual(1000, weigh_token_type(dummy_token("push")))
+        self.assertTrue(weigh_token_type(dummy_token("push")) > weigh_token_type(dummy_token("hotp")))
+        self.assertTrue(weigh_token_type(dummy_token("push")) > weigh_token_type(dummy_token("HOTP")))
+        self.assertTrue(weigh_token_type(dummy_token("PUSH")) > weigh_token_type(dummy_token("hotp")))
+
 
 class TokenOutOfBandTestCase(MyTestCase):
 
@@ -1697,6 +1737,7 @@ class TokenFailCounterTestCase(MyTestCase):
         g.policy_object = PolicyClass()
         g.audit_object = FakeAudit()
         g.client_ip = None
+        g.serial = None
         options = {"g": g}
 
         check_token_list([token1, token2], pin1, user=user,
